Stan Math Library: stan/math/fwd/scal/fun/multiply_log.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

multiply_log.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_MULTIPLY_LOG_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_MULTIPLY_LOG_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 #include <stan/math/prim/scal/fun/multiply_log.hpp>
7
8 namespace stan {
9
10 namespace math {
11
12 template <typename T>
13 inline
14 fvar<T>
15 multiply_log(const fvar<T>& x1, const fvar<T>& x2) {
16 using stan::math::multiply_log;
17 using std::log;
18 return fvar<T>(multiply_log(x1.val_, x2.val_),
19 x1.d_ * log(x2.val_) + x1.val_ * x2.d_ / x2.val_);
20 }
21
22 template <typename T>
23 inline
24 fvar<T>
25 multiply_log(const double x1, const fvar<T>& x2) {
26 using stan::math::multiply_log;
27 using std::log;
28 return fvar<T>(multiply_log(x1, x2.val_),
29 x1 * x2.d_ / x2.val_);
30 }
31
32 template <typename T>
33 inline
34 fvar<T>
35 multiply_log(const fvar<T>& x1, const double x2) {
36 using stan::math::multiply_log;
37 using std::log;
38 return fvar<T>(multiply_log(x1.val_, x2),
39 x1.d_ * log(x2));
40 }
41 }
42 }
43 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::log
fvar< T > log(const fvar< T > &x)
Definition: log.hpp:15
multiply_log.hpp
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::multiply_log
fvar< T > multiply_log(const fvar< T > &x1, const fvar< T > &x2)
Definition: multiply_log.hpp:15
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.